@@ -12,15 +12,18 @@
 #include <QIcon>
 #include <QTimer>
 
+#include <KIO/CopyJob>
+#include <KIO/PreviewJob>
 #include <KIO/RestoreJob>
-#include <kimagecache.h>
-#include <kio/copyjob.h>
-#include <kio/previewjob.h>
+
+using namespace Qt::StringLiterals;
 
 SortModel::SortModel(QObject *parent)
     : QSortFilterProxyModel(parent)
     , m_screenshotSize(256, 256)
     , m_containImages(false)
+    // using the same cache of the engine, they index both by url
+    , m_imageCache(std::make_unique<KImageCache>(QStringLiteral("org.kde.koko"), 10485760))
 {
     setSortLocaleAware(true);
     sort(0);
@@ -52,15 +55,9 @@ SortModel::SortModel(QObject *parent)
             }
         }
     });
-
-    // using the same cache of the engine, they index both by url
-    m_imageCache = new KImageCache(QStringLiteral("org.kde.koko"), 10485760);
 }
 
-SortModel::~SortModel()
-{
-    delete m_imageCache;
-}
+SortModel::~SortModel() = default;
 
 void SortModel::setContainImages(bool value)
 {
@@ -117,9 +114,9 @@ QVariant SortModel::data(const QModelIndex &index, int role) const
     }
 
     case Roles::Thumbnail: {
-        QUrl thumbnailSource(QString(/*"file://" + */ data(index, Roles::ImageUrlRole).toString()));
+        const QUrl thumbnailSource(data(index, Roles::ImageUrlRole).toString());
 
-        KFileItem item(thumbnailSource, QString());
+        const KFileItem item(thumbnailSource, QString());
         QImage preview = QImage(m_screenshotSize, QImage::Format_ARGB32_Premultiplied);
 
         if (m_imageCache->findImage(item.url().toString(), &preview)) {
@@ -128,7 +125,7 @@ QVariant SortModel::data(const QModelIndex &index, int role) const
 
         m_previewTimer->start(100);
         const_cast<SortModel *>(this)->m_filesToPreview[item.url()] = QPersistentModelIndex(index);
-        return {};
+        return false;
     }
 
     case Roles::SourceIndex: {
@@ -327,14 +324,22 @@ void SortModel::delayedPreview()
         const auto pluginLists = KIO::PreviewJob::availablePlugins();
         KIO::PreviewJob *job = KIO::filePreview(list, m_screenshotSize, &pluginLists);
         job->setIgnoreMaximumSize(true);
+#if KIO_VERSION >= QT_VERSION_CHECK(6, 15, 0)
+        connect(job, &KIO::PreviewJob::generated, this, &SortModel::showPreview);
+#else
         connect(job, &KIO::PreviewJob::gotPreview, this, &SortModel::showPreview);
+#endif
         connect(job, &KIO::PreviewJob::failed, this, &SortModel::previewFailed);
     }
 
     m_filesToPreview.clear();
 }
 
+#if KIO_VERSION >= QT_VERSION_CHECK(6, 15, 0)
+void SortModel::showPreview(const KFileItem &item, const QImage &preview)
+#else
 void SortModel::showPreview(const KFileItem &item, const QPixmap &preview)
+#endif
 {
     QPersistentModelIndex index = m_previewJobs.value(item.url());
     m_previewJobs.remove(item.url());
@@ -343,7 +348,11 @@ void SortModel::showPreview(const KFileItem &item, const QPixmap &preview)
         return;
     }
 
+#if KIO_VERSION >= QT_VERSION_CHECK(6, 15, 0)
+    m_imageCache->insertImage(item.url().toString(), preview);
+#else
     m_imageCache->insertImage(item.url().toString(), preview.toImage());
+#endif
     // qDebug() << "preview size:" << preview.size();
     emit dataChanged(index, index);
 }
